// Stats.cpp: implementation of the CStats class.
//
//////////////////////////////////////////////////////////////////////

#include "Stats.h"
#include "Calendar.h"
#include "WeatherReport.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CStats::CStats() : m_fRainfall(0.0), m_fSnowfall(0.0), m_fSnowDepth(0.0), m_nSunshine(0)
{
	clearTempStats();
}

CStats::~CStats()
{

}

void CStats::updatePrecip(float fAmount, float fDuration, bool bSnow)
{
    /* update yearly and daily statistics */
    m_fRainfall += fAmount/10.0;
    if (bSnow)
    {
        m_fSnowDepth += fAmount;
        m_fSnowfall += fAmount;
    }
	meltSnow(fDuration);
}

void CStats::meltSnow(float fDuration)
{
	CWeatherReport* pReport = CWeatherReport::instance();

	// rain will melt the snow
	if (!pReport->isSnow())
	{
		switch (pReport->getPrecip()) 
		{
		case CPrecip::SHOWER : 
			m_fSnowDepth -= fDuration;
			break;
		case CPrecip::HEAVY : 
			m_fSnowDepth -= fDuration *2;
			break;
		case CPrecip::STEADY :
			m_fSnowDepth -= 6;
			break;
		}
	}

	/* melt snow in weather above freezing */
	int nTemp = pReport->getTempDegrees();
	switch (pReport->getTemp()) 
	{
	case CTemperature::CHILLY :
		if (nTemp > 32) 
			m_fSnowDepth -= 0.5;
		break;
	case CTemperature::FAIR :
		m_fSnowDepth -= ((float)nTemp / 8.0);
		break;
	case CTemperature::WARM :
		m_fSnowDepth -= (float)nTemp - 40.0;
		break;
	case CTemperature::HOT : 
		m_fSnowDepth -= (float)nTemp - 20.0;
		break;
	}
	if (m_fSnowDepth < 0.1)
		m_fSnowDepth = 0.0;
}

void  CStats::updateTemp(int nMonth, int nTemp)
{
	m_nTempStats[nMonth][TOTAL] += nTemp;
	if (nTemp < m_nTempStats[nMonth][LOW])
	{
		m_nTempStats[nMonth][LOW] = nTemp;
	}
	if (nTemp > m_nTempStats[nMonth][HIGH])
	{
		m_nTempStats[nMonth][HIGH] = nTemp;
	}
}

void  CStats::incrSunshine()
{
	m_nSunshine++;
}

void  CStats::clearTempStats()
{

    for (int month = 0; month <= 12; month++)
    {
        m_nTempStats[month][LOW] = 200;
        for (int stat = AVERAGE; stat <= TOTAL; stat++)
            m_nTempStats[month][stat] = 0;
    }
}

void  CStats::clear()
{
	m_fRainfall = 0.0;
	m_fSnowfall = 0.0;
	m_nSunshine = 0;
	clearTempStats();
}

void CStats::calculateAverage(int nMonth)
{
	CCalendar* pCalendar = CCalendar::instance();

	m_nTempStats[nMonth][AVERAGE] = m_nTempStats[nMonth][TOTAL] / pCalendar->getMonthLength(nMonth);
}

float CStats::getRainfall() const
{
	return m_fRainfall;
}

float CStats::getSnowfall() const
{
	return m_fSnowfall;
}

float CStats::getSnowDepth() const
{
	return m_fSnowDepth;
}

int CStats::getSunshine() const
{
	return m_nSunshine;
}


int CStats::getTempStat(int nMonth, int nStat) const
{
	return m_nTempStats[nMonth][nStat];
}


