// Temperature.cpp: implementation of the CTemperature class.
//
//////////////////////////////////////////////////////////////////////

#include <cstddef>

#include "Temperature.h"
#include "WeatherReport.h"
#include "Climate.h"
#include "Dice.h"

string CTemperature::m_strNames[] = {
    "Cold",
    "Chilly",
    "Fair",
    "Warm",
    "Hot",
};

int CTemperature::m_nVariationTable[] = {1, 5, 13, 25, 75, 87, 95, 99, 100};

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CTemperature::CTemperature(int nTemp)
{
	m_nType = nTemp;
}

CTemperature::~CTemperature()
{

}

CTemperature& CTemperature::operator=(const CTemperature& rhs)
{
	m_nType = rhs.m_nType;
	m_nTemperature = rhs.m_nTemperature;
	return *this;
}

string CTemperature::getName() const
{
	return m_strNames[m_nType];
}

int CTemperature::getDegrees() const
{
	return m_nTemperature;
}

void CTemperature::randomType()
{
	 m_nTemperature = randomTemp();

     /* classify the temperature class */
     if (m_nTemperature < 25) 
         m_nType = COLD;
     else
     if ((m_nTemperature >= 25) && (m_nTemperature < 40)) 
         m_nType = CHILLY;
     else
     if ((m_nTemperature >= 40) && (m_nTemperature < 65)) 
         m_nType = FAIR;
     else
     if ((m_nTemperature >= 65) && (m_nTemperature < 80)) 
         m_nType = WARM;
     else
     if (m_nTemperature >= 80) 
         m_nType = HOT;
}

int CTemperature::randomTemp()
{
     /* determine temperature variation from monthly average */
     /*   +/- 20 degrees */
     int roll = CDice::roll(100);
     int data = 8;
     for (int i = 8; i >= 0; i--)
	 {
         if (roll <= m_nVariationTable[i])
		 {
             data = i;
		 }
	 }
	 CWeatherReport* pReport = CWeatherReport::instance();
	 CClimate* pClimate = pReport->getClimate();
	 int nMonth = pReport->getMonth();
	 return ( pClimate->getAveTemp(nMonth) + ((data-4) * 5) );
}


